<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="fr" sourcelanguage="">
<context>
    <name>JupyterConsole_preferences</name>
    <message>
        <location filename="../JupyterConsole/preferences.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../JupyterConsole/preferences.ui" line="35"/>
        <source>Jupyter Console</source>
        <translation>Jupyter Console</translation>
    </message>
    <message>
        <location filename="../JupyterConsole/preferences.ui" line="59"/>
        <source>Default kernel</source>
        <translation>Noyau par défaut</translation>
    </message>
    <message>
        <location filename="../JupyterConsole/preferences.ui" line="66"/>
        <source>Focus shortcut</source>
        <translation>Raccourci d&apos;activation</translation>
    </message>
    <message>
        <location filename="../JupyterConsole/preferences.ui" line="76"/>
        <source>Start inprocess kernel (for developers)</source>
        <translation>Démarrer le noyau inprocess (pour développeurs)</translation>
    </message>
</context>
<context>
    <name>JupyterNotebook_launch_widget</name>
    <message>
        <location filename="../JupyterNotebook/launch_jupyter_lab_widget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../JupyterNotebook/launch_jupyter_lab_widget.ui" line="38"/>
        <source>Launch Jupyter Lab</source>
        <translation>Démarrer Jupyter Lab</translation>
    </message>
    <message>
        <location filename="../JupyterNotebook/launch_jupyter_lab_widget.ui" line="55"/>
        <source>Kill Jupyter Lab</source>
        <translation>Tuer Jupyter Lab</translation>
    </message>
</context>
<context>
    <name>JupyterNotebook_preferences</name>
    <message>
        <location filename="../JupyterNotebook/preferences.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../JupyterNotebook/preferences.ui" line="35"/>
        <source>Jupyter Notebook / Lab</source>
        <translation>Jupyter Notebook / Lab</translation>
    </message>
    <message>
        <location filename="../JupyterNotebook/preferences.ui" line="59"/>
        <source>Executable</source>
        <translation>Fichier exécutable</translation>
    </message>
    <message>
        <location filename="../JupyterNotebook/preferences.ui" line="69"/>
        <source>Arguments</source>
        <translation>Arguments</translation>
    </message>
    <message>
        <location filename="../JupyterNotebook/preferences.ui" line="79"/>
        <source>If left empty, the jupyter-lab executable is autodetected and started with the home folder as the notebook folder.</source>
        <translation>Par défaut, le fichier exécutable de jupyter-lab est détecté automatiquement et lancé avec le dossier de départ en tant que dossier de notebook.</translation>
    </message>
</context>
<context>
    <name>OpenSesameIDE_preferences</name>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="35"/>
        <source>Rapunzel IDE: Appearance and behavior</source>
        <translation>Rapunzel IDE : Apparence et comportement</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="59"/>
        <source>Automatically save before running file</source>
        <translation>Enregistrer automatiquement avant l&apos;exécution d&apos;un fichier</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="69"/>
        <source>Default file extension</source>
        <translation>Extension de fichier par défaut</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="76"/>
        <source>Change working directory before running selection</source>
        <translation>Changer le répertoire de travail avant l&apos;exécution d&apos;une sélection</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="83"/>
        <source>Automatically convert tabs to spaces</source>
        <translation>Convertir des tabulations en espaces automatiquement</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="90"/>
        <source>Automatically strip trailing whitespace</source>
        <translation>Supprimer les espaces de fin automatiquement</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="117"/>
        <source>Rapunzel IDE: Keyboard shortcuts</source>
        <translation>Rapunzel IDE : Raccourcis clavier</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="141"/>
        <source>Run project or file</source>
        <translation>Exécuter projet ou fichier</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="148"/>
        <source>Run selection, cell, or current line</source>
        <translation>Exécuter la sélection, la cellule ou la ligne actuelle</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="155"/>
        <source>Interrupt kernel</source>
        <translation>Interrompre le noyau</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="162"/>
        <source>Change working directory to active file</source>
        <translation>Changer le répertoire de travail vers le fichier actuel</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="169"/>
        <source>Toggle fullscreen</source>
        <translation>Basculer mode plein écran</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="176"/>
        <source>Close tab</source>
        <translation>Fermer l&apos;onglet</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="183"/>
        <source>Close other tabs</source>
        <translation>Fermer les autres onglets</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="190"/>
        <source>Close all tabs</source>
        <translation>Fermer tous les onglets</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="197"/>
        <source>Split vertical</source>
        <translation>Division vertical</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="204"/>
        <source>Split horizontal</source>
        <translation>Division horizontal</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="211"/>
        <source>Switch to previous panel</source>
        <translation>Passer au panneau précedent</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="218"/>
        <source>Switch to next panel</source>
        <translation>Passer au panneau précedent</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="225"/>
        <source>Toggle folder browsers</source>
        <translation>Basculer les navigateurs de dossiers</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="232"/>
        <source>Locate active file</source>
        <translation>Localiser le fichier actuel</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="97"/>
        <source>Use system default file encoding</source>
        <translation>Utiliser l&apos;encodage des fichiers par défaut du système</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="107"/>
        <source>Default file encoding</source>
        <translation>Encodage des fichiers par défaut</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="281"/>
        <source>Run file in debugger</source>
        <translation>Exécuter le fichier dans le débogueur</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="288"/>
        <source>Toggle breakpoint</source>
        <translation>Basculer un point d&apos;arrêt</translation>
    </message>
    <message>
        <location filename="../OpenSesameIDE/preferences.ui" line="295"/>
        <source>Clear breakpoints</source>
        <translation>Enlever les points d&apos;arret</translation>
    </message>
</context>
<context>
    <name>SpellCheck_preferences</name>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="35"/>
        <source>Spell checker</source>
        <translation>Vérificateur orthographique</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="59"/>
        <source>Default language</source>
        <translation>Langue par défaut</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="67"/>
        <source>en</source>
        <translation>en</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="72"/>
        <source>fr</source>
        <translation>fr</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="77"/>
        <source>de</source>
        <translation>de</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="82"/>
        <source>pt</source>
        <translation>pt</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="87"/>
        <source>es</source>
        <translation>es</translation>
    </message>
    <message>
        <location filename="../SpellCheck/preferences.ui" line="95"/>
        <source>Enabled mimetypes</source>
        <translation>Mimetypes activés</translation>
    </message>
</context>
<context>
    <name>SymbolSelector_preferences</name>
    <message>
        <location filename="../SymbolSelector/preferences.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../SymbolSelector/preferences.ui" line="35"/>
        <source>Symbol selector</source>
        <translation>Sélecteur de symboles</translation>
    </message>
    <message>
        <location filename="../SymbolSelector/preferences.ui" line="59"/>
        <source>Keyboard shortcut</source>
        <translation>Raccourci clavier</translation>
    </message>
</context>
<context>
    <name>extension_CommandPalette</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="134"/>
        <source>Trigger menu actions</source>
        <translation>Activer les actions du menu</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="133"/>
        <source>Command palette</source>
        <translation>Palette de commandes</translation>
    </message>
</context>
<context>
    <name>extension_DataViewer</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="96"/>
        <source>Load into workspace (DataMatrix) and view</source>
        <translation>Charger dans l&apos;espace de travail (DataMatrix) et afficher</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="98"/>
        <source>DataViewer</source>
        <translation>DataViewer</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="97"/>
        <source>Load into workspace (PIL image) and view</source>
        <translation>Charger dans l&apos;espace de travail (image PIL) et afficher</translation>
    </message>
</context>
<context>
    <name>extension_FindInFiles</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="93"/>
        <source>Find in project files</source>
        <translation>Rechercher dans les fichiers des projets</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="90"/>
        <source>Find text in project files</source>
        <translation>Trouver du text dans les fichiers des projets</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="92"/>
        <source>FindInFiles requires the OpenSesameIDE extension</source>
        <translation>FindInFiles à besoin de l&apos;extension OpenSesameIDE</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="91"/>
        <source>Find in projects</source>
        <translation>Recherchers dans les projets</translation>
    </message>
</context>
<context>
    <name>extension_GitGUI</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="3"/>
        <source>Start Git GUI</source>
        <translation>Démarrer Git GUI</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="5"/>
        <source>Starts Git GUI</source>
        <translation>Démarre Git GUI</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="4"/>
        <source>Launch Git GUI</source>
        <translation>Lancer Git GUI</translation>
    </message>
</context>
<context>
    <name>extension_JupyterConsole</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="140"/>
        <source>Show Jupyter/ IPython console</source>
        <translation>Montrer la console Jupyter/ IPython</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="138"/>
        <source>Restart kernel</source>
        <translation>Redémarrer le noyau</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="137"/>
        <source>Start new console</source>
        <translation>Lancer une nouvelle console</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="139"/>
        <source>Show console</source>
        <translation>Montrer la console</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="141"/>
        <source>The {} (inprocess={}) kernel does not support debugging</source>
        <translation>Le noyau {} (inprocess={}) ne prend pas en charge le débogage</translation>
    </message>
</context>
<context>
    <name>extension_JupyterNotebook</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="12"/>
        <source>Open Jupyter/ IPython Notebook</source>
        <translation>Ouvrir Notebook Jupyter/ IPython</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="8"/>
        <source>Import notebook</source>
        <translation>Importer notebook</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="9"/>
        <source>Failed to read notebook. See console for details.</source>
        <translation>Le chargement du notebook à échoué. Voir la console pour plus de details.</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="10"/>
        <source>Launch Jupyter Lab</source>
        <translation>Démarrer Jupyter Lab</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="11"/>
        <source>Export notebook</source>
        <translation>Exporter notebook</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="13"/>
        <source>Import and export Jupyter Notebook (.ipynb) files</source>
        <translation>Importer et exporter des fichiers Jupyter Notebook (.ipynb)</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="14"/>
        <source>Import as Python script</source>
        <translation>Importer en tant que script de Python</translation>
    </message>
</context>
<context>
    <name>extension_OpenSesameIDE</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="69"/>
        <source>Open file</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="40"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="85"/>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="80"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="53"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="63"/>
        <source>&amp;Interrupt kernel</source>
        <translation>&amp;Interrompre le noyau</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="87"/>
        <source>Not indexing {} (too many files)</source>
        <translation>Pas d&apos;indexation de {} (trop de fichiers)</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="30"/>
        <source>Running notebook cell</source>
        <translation>Exécuter cellule de notebook</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="31"/>
        <source>Split &amp;vertical</source>
        <translation>Division &amp;vertical</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="70"/>
        <source>Fixed editor width</source>
        <translation>Largeur de l&apos;éditeur fixée</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="74"/>
        <source>Run &amp;selection, cell, or current line</source>
        <translation>Exécuter la &amp;sélection, la cellule ou la ligne actuelle</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="54"/>
        <source>Running current line</source>
        <translation>En train d&apos;exécuter la ligne actuelle</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="67"/>
        <source>How do you want to open this file?</source>
        <translation>Comment voulez-vous ouvrir ce fichier ?</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="58"/>
        <source>Close &amp;all tabs</source>
        <translation>Fermer &amp;tous les onglets</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="35"/>
        <source>Code completion</source>
        <translation>Complétion de code</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="32"/>
        <source>&amp;Locate active file</source>
        <translation>&amp;Localiser le fichier actuel</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="79"/>
        <source>Select indentation mode</source>
        <translation>Sélectionner le mode d&apos;indentation</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="68"/>
        <source>Wrap lines</source>
        <translation>Retour à ligne</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="61"/>
        <source>Open as text</source>
        <translation>Ouvrir comme texte</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="41"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="76"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="29"/>
        <source>Switch to previous panel</source>
        <translation>Passer au panneau précedent</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="73"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="66"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="49"/>
        <source>Code folding</source>
        <translation>Pliage de code</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="37"/>
        <source>Turn OpenSesame into an IDE</source>
        <translation>Changer OpenSesame en IDE</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="42"/>
        <source>P&amp;lugins</source>
        <translation>P&amp;lugins</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="48"/>
        <source>Switch to next panel</source>
        <translation>Passer au panneau suivant</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="36"/>
        <source>Running project</source>
        <translation>En train d&apos;exécuter le projet</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="64"/>
        <source>Close &amp;other tabs</source>
        <translation>Fermer les &amp;autres onglets</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="56"/>
        <source>&amp;Run</source>
        <translation>&amp;Exécuter</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="62"/>
        <source>&amp;Close tab</source>
        <translation>&amp;Fermer l&apos;onglet</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="65"/>
        <source>Restart &amp;kernel</source>
        <translation>Redémarrer le &amp;noyau</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="50"/>
        <source>Save and run</source>
        <translation>Enregistrer et exécuter</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="83"/>
        <source>Show right margin</source>
        <translation>Montrer la marge droite</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="43"/>
        <source>Running file</source>
        <translation>En train d&apos;exécuter le fichier</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="78"/>
        <source>Split &amp;horizontal</source>
        <translation>Division &amp;horizontal</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="86"/>
        <source>Show editor tabs</source>
        <translation>Montrer les onglets de l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="81"/>
        <source>Unsaved changes</source>
        <translation>Modifications non enregistrées</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="55"/>
        <source>Running selection</source>
        <translation>En train d&apos;exécuter la sélection</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="60"/>
        <source>Show whitespace</source>
        <translation>Montrer les espaces</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="59"/>
        <source>&amp;Close all folders</source>
        <translation>&amp;Fermer tous les navigateurs de dossiers</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="39"/>
        <source>Show line numbers</source>
        <translation>Montrer les numéros des lignes</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="52"/>
        <source>Toggle fullscreen</source>
        <translation>Basculer mode plein écran</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="51"/>
        <source>&amp;Editor</source>
        <translation>&amp;Éditeur</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="47"/>
        <source>&amp;Run project or file</source>
        <translation>&amp;Exécuter projet ou fichier</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="75"/>
        <source>Change &amp;working directory to active file</source>
        <translation>Changer le &amp;répertoire de travail vers le fichier actuel</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="45"/>
        <source>Toggle &amp;folder browsers</source>
        <translation>Basculer les &amp;navigateurs de dossiers</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="36"/>
        <source>Search project files or browse disk ?</source>
        <translation type="obsolete">Rechercher dans les fichiers des projets ou parcourir le disque …</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="62"/>
        <source>Open &amp;folder?</source>
        <translation type="obsolete">Ouvrir un &amp;dossier…</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="28"/>
        <source>Browse disk ?</source>
        <translation type="obsolete">Parcourir le disque …</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="55"/>
        <source>&amp;Open?</source>
        <translation type="obsolete">&amp;Ouvrir…</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="75"/>
        <source>Search recent folders or browse disk ?</source>
        <translation type="obsolete">Rechercher dans les fichiers récents ou parcourir le disque …</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="29"/>
        <source>Save &amp;as?</source>
        <translation type="obsolete">Enregistrer &amp;sous…</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="82"/>
        <source>Save, run, and don&apos;t ask again</source>
        <translation>Enregistrer, exécuter, et ne plus demander</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="72"/>
        <source>Search project files or browse disk …</source>
        <translation>Rechercher dans les fichiers des projets ou parcourir le disque …</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="38"/>
        <source>Save &amp;as…</source>
        <translation>Enregistrer &amp;sous…</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="71"/>
        <source>Browse disk …</source>
        <translation>Parcourir le disque …</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="44"/>
        <source>Open &amp;folder…</source>
        <translation>Ouvrir un &amp;dossier…</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="77"/>
        <source>&amp;Open…</source>
        <translation>&amp;Ouvrir…</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="84"/>
        <source>Search recent folders or browse disk …</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="57"/>
        <source>Cannot save file with this encoding</source>
        <translation>Ne peut pas enregistrer le fichier avec cet encodage</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="46"/>
        <source>Run file in &amp;debugger</source>
        <translation>Exécuter le fichier dans le &amp;débogueur</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="34"/>
        <source>Clear &amp;breakpoints</source>
        <translation>Enlever les &amp;points d&apos;arret</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="33"/>
        <source>&amp;Toggle breakpoint</source>
        <translation>&amp;Basculer un point d&apos;arrêt</translation>
    </message>
</context>
<context>
    <name>extension_PythonDebugger</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="130"/>
        <source>Connects to the Rapunzel PDB</source>
        <translation>Se connecte avec le débogueur Rapunzel</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="129"/>
        <source>Python Debugger</source>
        <translation>Débogueur Python</translation>
    </message>
</context>
<context>
    <name>extension_QuickSelector</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="121"/>
        <source>A general-purpose quick-select dialog</source>
        <translation>Une boîte de dialogue de sélection rapide à usage général</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="122"/>
        <source>Select stuff quickly</source>
        <translation>Sélectionner des choses rapidement</translation>
    </message>
</context>
<context>
    <name>extension_RapunzelLocale</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="112"/>
        <source>Installs translation for Rapunzel extensions</source>
        <translation>Installe la traduction des extensions Rapunzel</translation>
    </message>
</context>
<context>
    <name>extension_RapunzelWelcome</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="125"/>
        <source>Get started!</source>
        <translation>Lancez-vous !</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="126"/>
        <source>A welcome tab for Rapunzel</source>
        <translation>Un onglet de bienvenue pour Rapunzel</translation>
    </message>
</context>
<context>
    <name>extension_SpellCheck</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="102"/>
        <source>Check spelling</source>
        <translation>Vérifier l&apos;ortographe</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="101"/>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="103"/>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="104"/>
        <source>Please install pyspellchecker for spell checking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="105"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="106"/>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="107"/>
        <source>Set language for spell checking …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="108"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="109"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>extension_SymbolSelector</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="19"/>
        <source>Symbol selector</source>
        <translation>Sélecteur de symboles</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="18"/>
        <source>Quickly jump to functions, classes, and other symbol definitions</source>
        <translation>Accédez rapidement aux fonctions, classes et autres définitions de symboles</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../translation_tools/translatables.py" line="17"/>
        <source>Search symbols in current file …</source>
        <translation>Rechercher des symboles dans le fichier actuel …</translation>
    </message>
</context>
<context>
    <name>extension_WordCount</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="117"/>
        <source>Word count</source>
        <translation>Nombre de mot</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="115"/>
        <source>{} lines, {} words, {} characters</source>
        <translation>{} lignes, {} mots, {} caractères</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="116"/>
        <source>Nothing to count</source>
        <translation>Rien à compter</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="118"/>
        <source>Counts the number of lines, words, and characters</source>
        <translation>Compte le nombre de lignes, de mots et de caractères</translation>
    </message>
</context>
<context>
    <name>extension_WorkspaceExplorer</name>
    <message>
        <location filename="../../translation_tools/translatables.py" line="22"/>
        <source>Workspace ({})</source>
        <translation>Espace de travail ({})</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="23"/>
        <source>Show Python workspace explorer</source>
        <translation>Afficher l&apos;explorateur d&apos;espace de travail Python</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="24"/>
        <source>Show workspace</source>
        <translation>Afficher l&apos;espace de travail</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="26"/>
        <source>Workspace</source>
        <translation>Espace de travail</translation>
    </message>
    <message>
        <location filename="../../translation_tools/translatables.py" line="25"/>
        <source>Cannot inspect variables in running kernel</source>
        <translation>Ne peut pas visualiser des variables à partir d&apos;un noyau en cours d&apos;exécution</translation>
    </message>
</context>
<context>
    <name>find_in_files</name>
    <message>
        <location filename="../FindInFiles/find_in_files.ui" line="14"/>
        <source>Find in files</source>
        <translation>Rechercher dans les fichiers</translation>
    </message>
    <message>
        <location filename="../FindInFiles/find_in_files.ui" line="69"/>
        <source>Text to find</source>
        <translation>Texte à trouver</translation>
    </message>
    <message>
        <location filename="../FindInFiles/find_in_files.ui" line="94"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../FindInFiles/find_in_files.ui" line="105"/>
        <source>Find</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../FindInFiles/find_in_files.ui" line="122"/>
        <source>File/ directory pattern, e.g. *.py</source>
        <translation>Modèle de fichier/ répertoire, par exemple *.py</translation>
    </message>
</context>
</TS>
